package net.sourceforge.datagenerator;

/*
 * JDBC Importer - database import utility/framework.
 * Copyright (C) 2002 Chris Nagy
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Chris Nagy
 * Email:  cnagyxyz@hotmail.com
 */

import net.sourceforge.jdbcimporter.ColumnDef;

/**
 * The GenerateColumnDef class represents a column whose values will be 
 * generated by the DataGenerator.
 * 
 * @version 	0.6
 * @author Chris Nagy
 */
public class GenerateColumnDef extends ColumnDef 
{
	/**
	 * The column value generator.
	 */
	ColumnValueGenerator generator;

	/**
	 * Sets the generator used to generate values for this column.
	 * 
	 * @param gen the generator
	 */		
	public void setColumnValueGenerator( ColumnValueGenerator gen )
	{
		this.generator = gen;
		this.generator.setColumnDef( this );
	}
	
	/**
	 * Returns the generator used to generate values for this column.
	 * 
	 * @return the generator
	 */
	public ColumnValueGenerator getColumnValueGenerator()
	{
		return this.generator;
	}

	/**
	 * Overrides Object.toString()
	 */
	public String toString()
	{
		StringBuffer buf = new StringBuffer("GenerateColumnDef : ");
		buf.append( "name = '"+getName()+"', ");
		buf.append( "type = '"+getType()+"', ");
		buf.append( "defaultValue = '"+getDefaultValue()+"', ");
		buf.append( "formatPattern = '"+getFormatPattern()+"', ");
		buf.append( "columnValueGenerator = "+getColumnValueGenerator()+"\n");
		return buf.toString();
	}
	
}
